@@ -3,7 +3,7 @@
  * File:	dwww-cache.c
  * Purpose:	Manage the dwww cache of converted documents.
  * Author:	Lars Wirzenius
- * Version:	"(#)dwww:$Id: dwww-cache.c,v 1.12 2002/11/24 23:17:22 robert Exp $"
+ * Version:	"(#)dwww:$Id: dwww-cache.c,v 1.14 2005/03/08 20:15:10 robert Exp $"
  * Description:	See the manual page for how to use this program.
  *
  *		Basically, what we do is read in a file from stdin,
@@ -119,7 +119,7 @@ struct dochash {
 /*
  * Where we store the files and the database.
  */
-#define SPOOL_DIR "/var/cache/dwww/"
+#define SPOOL_DIR "/var/cache/dwww/db/"
 
 /*
  * The name of the database in SPOOL_DIR.
